==> qt-creator-opensource-src-3.1.2.tar.gz: qt-creator-opensource-src-3.1.2/src/plugins/cpptools/cpphighlightingsupport.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef CPPTOOLS_CPPHIGHLIGHTINGSUPPORT_H
#define CPPTOOLS_CPPHIGHLIGHTINGSUPPORT_H

#include "cpptools_global.h"

#include <texteditor/semantichighlighter.h>

#include <cplusplus/CppDocument.h>

#include <QFuture>

namespace TextEditor { class ITextEditor; }

namespace CppTools {

class CPPTOOLS_EXPORT CppHighlightingSupport
{
public:
    enum Kind {
        Unknown = 0,
        TypeUse,
        LocalUse,
        FieldUse,
        EnumerationUse,
        VirtualMethodUse,
        LabelUse,
        MacroUse,
        FunctionUse,
        PseudoKeywordUse,
        StringUse
    };

public:
    CppHighlightingSupport(TextEditor::ITextEditor *editor);
    virtual ~CppHighlightingSupport() = 0;

    virtual bool requiresSemanticInfo() const = 0;

    virtual bool hightlighterHandlesDiagnostics() const = 0;
    virtual bool hightlighterHandlesIfdefedOutBlocks() const = 0;

    virtual QFuture<TextEditor::HighlightingResult> highlightingFuture(
            const CPlusPlus::Document::Ptr &doc,
            const CPlusPlus::Snapshot &snapshot) const = 0;

protected:
    TextEditor::ITextEditor *editor() const
    { return m_editor; }

private:
    TextEditor::ITextEditor *m_editor;
};

} // namespace CppTools

#endif // CPPTOOLS_CPPHIGHLIGHTINGSUPPORT_H

==> qt-creator-opensource-src-3.2.2.tar.gz: qt-creator-opensource-src-3.2.2/src/plugins/cpptools/cpphighlightingsupport.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef CPPTOOLS_CPPHIGHLIGHTINGSUPPORT_H
#define CPPTOOLS_CPPHIGHLIGHTINGSUPPORT_H

#include "cpptools_global.h"

#include <texteditor/semantichighlighter.h>

#include <cplusplus/CppDocument.h>

#include <QFuture>

namespace TextEditor { class BaseTextDocument; }

namespace CppTools {

class CPPTOOLS_EXPORT CppHighlightingSupport
{
public:
    enum Kind {
        Unknown = 0,
        TypeUse,
        LocalUse,
        FieldUse,
        EnumerationUse,
        VirtualMethodUse,
        LabelUse,
        MacroUse,
        FunctionUse,
        PseudoKeywordUse,
        StringUse
    };

public:
    CppHighlightingSupport(TextEditor::BaseTextDocument *baseTextDocument);
    virtual ~CppHighlightingSupport() = 0;

    virtual bool requiresSemanticInfo() const = 0;

    virtual bool hightlighterHandlesDiagnostics() const = 0;
    virtual bool hightlighterHandlesIfdefedOutBlocks() const = 0;

    virtual QFuture<TextEditor::HighlightingResult> highlightingFuture(
            const CPlusPlus::Document::Ptr &doc,
            const CPlusPlus::Snapshot &snapshot) const = 0;

protected:
    TextEditor::BaseTextDocument *baseTextDocument() const
    { return m_baseTextDocument; }

private:
    TextEditor::BaseTextDocument *m_baseTextDocument;
};

} // namespace CppTools

#endif // CPPTOOLS_CPPHIGHLIGHTINGSUPPORT_H
